@@ -35,11 +35,15 @@ store_cast_object.tar_feather <- function(store, object) {
 
 #' @export
 store_assert_format.tar_feather <- function(store, object, name) { # nolint
-  msg <- paste0(
-    "target ", name, " did not return a data frame. ",
-    "Target with format = \"feather\" must return data frames."
+  msg <- paste(
+    "target", name, "has feather format, so it must have class",
+    "data.frame, RecordBatch, or Table."
+  )
+  tar_assert_inherits(
+    x = object,
+    class = c("data.frame", "RecordBatch", "Table"),
+    msg = msg
   )
-  tar_assert_df(object, msg)
 }
 
 #' @export
