@@ -2,6 +2,7 @@ passive_new <- function(
   pipeline = NULL,
   meta = NULL,
   names = NULL,
+  shortcut = NULL,
   queue = NULL,
   reporter = NULL
 ) {
@@ -9,6 +10,7 @@ passive_new <- function(
     pipeline = pipeline,
     meta = meta,
     names = names,
+    shortcut = shortcut,
     queue = queue,
     reporter = reporter
   )
@@ -28,9 +30,10 @@ passive_class <- R6::R6Class(
     },
     start = function() {
       pipeline_prune_names(self$pipeline, self$names)
+      self$ensure_meta()
       pipeline_reset_priorities(self$pipeline)
       self$update_scheduler()
-      self$ensure_meta()
+      self$bootstrap_shortcut_deps()
       self$scheduler$reporter$report_start()
     },
     end = function() {
