@@ -4,6 +4,7 @@ prelocal_new <- function(
   names = NULL,
   queue = NULL,
   reporter = NULL,
+  envir = NULL,
   scheduler = NULL
 ) {
   prelocal_class$new(
@@ -12,6 +13,7 @@ prelocal_new <- function(
     names = names,
     queue = queue,
     reporter = reporter,
+    envir = envir,
     scheduler = scheduler
   )
 }
@@ -28,6 +30,7 @@ prelocal_class <- R6::R6Class(
       names = NULL,
       queue = NULL,
       reporter = NULL,
+      envir = NULL,
       scheduler = NULL
     ) {
       super$initialize(
@@ -35,6 +38,7 @@ prelocal_class <- R6::R6Class(
         meta = meta,
         names = names,
         queue = queue,
+        envir = envir,
         reporter = reporter
       )
       self$scheduler <- scheduler
@@ -43,14 +47,14 @@ prelocal_class <- R6::R6Class(
     },
     end = function() {
     },
-    assert_deployment = function(target) {
+    tar_assert_deployment = function(target) {
       should_abort <- identical(target$settings$deployment, "worker") &&
         inherits(target, "tar_builder")
       if (should_abort) {
         name <- target_get_name(target)
         rank <- rank_offset(target$settings$priority)
         self$scheduler$queue$prepend(name, rank)
-        throw_prelocal("requires workers")
+        tar_throw_prelocal("requires workers")
       }
     }
   )
