@@ -294,14 +294,15 @@ tar_assert_lgl <- function(x, msg = NULL) {
 tar_assert_name <- function(x) {
   tar_assert_chr(x)
   tar_assert_scalar(x)
-  if (!nzchar(x)) {
-    tar_throw_validate("name must be a nonempty string.")
-  }
+  tar_assert_nzchar(x)
   if (!identical(x, make.names(x))) {
     tar_throw_validate(x, " is not a valid symbol name.")
   }
+  if (grepl("^\\.", x)) {
+    tar_throw_validate("a target name cannot begin with a dot. Found: ", x)
+  }
   if (grepl("\\.$", x)) {
-    tar_throw_validate(x, " ends with a dot.")
+    tar_throw_validate("a target name cannot end with a dot. Found: ", x)
   }
 }
 
@@ -463,9 +464,11 @@ tar_assert_target <- function(x, msg = NULL) {
 #' @rdname tar_assert
 tar_assert_target_list <- function(x) {
   msg <- paste(
-    "The target script file (default: _targets.R)",
-    "must end with a list of tar_target() objects (recommended)",
-    "or a tar_pipeline() object (deprecated). Each element of the target list",
+    "Expected a list of target objects but did not find one.",
+    "Are you missing a target list at the end of your target script file?",
+    "The target script file (e.g. _targets.R)",
+    "must end with a list of tar_target() objects.",
+    "Each element of the target list",
     "must be a target object or nested list of target objects."
   )
   tar_assert_list(x, msg = msg)
