@@ -17,15 +17,7 @@ tar_test("tar_timestamp() for URLs", {
   tar_make(callr_function = NULL)
   # correctly parsed posix object
   out <- tar_timestamp(abc)
-  expect_equal(length(out), 2L)
+  expect_equal(length(out), 1L)
   expect_true(inherits(out, "POSIXct"))
   expect_false(anyNA(out))
-  # incorrectly parsed posix object
-  out <- tar_timestamp(abc, format = "%h %h %h %h %h")
-  expect_equal(as.numeric(out), as.numeric(file_time_reference))
-  # unparsed time stamp
-  out <- tar_timestamp(abc, parse = FALSE, format = "%h %h %h %h %h")
-  expect_equal(length(out), 2L)
-  expect_false(anyNA(out))
-  expect_true(is.character(out))
 })
